==> share-0.2.4-sources.jar: threads/share/DontShowAgainDialog.java <==
package threads.share;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.util.Log;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.widget.CheckBox;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AlertDialog;
import androidx.fragment.app.DialogFragment;

import static androidx.core.util.Preconditions.checkNotNull;

public class DontShowAgainDialog extends DialogFragment {
    public static final String TAG = DontShowAgainDialog.class.getSimpleName();
    public static final String TEXT = "TEXT";

    public ActionListener listener;
    private Context mContext;

    @Override
    public void onDetach() {
        super.onDetach();
        listener = null;
        mContext = null;
    }


    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        mContext = context;
        try {
            listener = (DontShowAgainDialog.ActionListener) getActivity();
        } catch (Throwable e) {
            Log.e(TAG, "" + e.getLocalizedMessage(), e);
        }
    }

    @Override
    @NonNull
    public Dialog onCreateDialog(Bundle savedInstanceState) {

        Activity activity = getActivity();
        checkNotNull(activity);

        AlertDialog.Builder builder = new AlertDialog.Builder(mContext);
        LayoutInflater inflater = activity.getLayoutInflater();

        Bundle bundle = getArguments();
        checkNotNull(bundle);
        String text = bundle.getString(TEXT);
        checkNotNull(text);


        @SuppressWarnings("all")
        View view = inflater.inflate(R.layout.checkbox, null);
        CheckBox dontShowAgain = view.findViewById(R.id.skip);
        dontShowAgain.setOnClickListener((v) -> {
            listener.accept(dontShowAgain.isChecked());
            dismiss();
        });

        builder.setView(view).setMessage(text);

        Dialog dialog = builder.create();

        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);

        Window window = dialog.getWindow();
        if (window != null) {
            window.getAttributes().windowAnimations = R.style.DialogTopAnimation;
            window.getAttributes().gravity = Gravity.TOP | Gravity.CENTER;
            window.setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
            window.setBackgroundDrawable(new ColorDrawable(android.graphics.Color.TRANSPARENT));
        }
        return dialog;
    }

    public interface ActionListener {

        void accept(boolean dontShowAgain);

    }
}

==> share-0.2.5-sources.jar: threads/share/DontShowAgainDialog.java <==
package threads.share;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.util.Log;
import android.util.TypedValue;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.widget.CheckBox;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AlertDialog;
import androidx.fragment.app.DialogFragment;

import static androidx.core.util.Preconditions.checkNotNull;

public class DontShowAgainDialog extends DialogFragment {
    public static final String TAG = DontShowAgainDialog.class.getSimpleName();
    public static final String TEXT = "TEXT";

    public ActionListener listener;
    private Context mContext;
    private int backgroundColor;
    @Override
    public void onDetach() {
        super.onDetach();
        listener = null;
        mContext = null;
    }


    private static int getThemeBackgroundColor(final Context context) {
        final TypedValue value = new TypedValue();
        context.getTheme().resolveAttribute(android.R.attr.windowBackground, value, true);
        return value.data;
    }
    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        mContext = context;
        try {
            listener = (DontShowAgainDialog.ActionListener) getActivity();
            backgroundColor = getThemeBackgroundColor(context);
        } catch (Throwable e) {
            Log.e(TAG, "" + e.getLocalizedMessage(), e);
        }
    }

    @Override
    @NonNull
    public Dialog onCreateDialog(Bundle savedInstanceState) {

        Activity activity = getActivity();
        checkNotNull(activity);

        AlertDialog.Builder builder = new AlertDialog.Builder(mContext);
        LayoutInflater inflater = activity.getLayoutInflater();

        Bundle bundle = getArguments();
        checkNotNull(bundle);
        String text = bundle.getString(TEXT);
        checkNotNull(text);


        @SuppressWarnings("all")
        View view = inflater.inflate(R.layout.checkbox, null);


        view.setBackgroundColor(backgroundColor);


        CheckBox dontShowAgain = view.findViewById(R.id.skip);
        dontShowAgain.setOnClickListener((v) -> {
            listener.accept(dontShowAgain.isChecked());
            dismiss();
        });

        builder.setView(view).setMessage(text);

        Dialog dialog = builder.create();

        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);

        Window window = dialog.getWindow();
        if (window != null) {
            window.getAttributes().windowAnimations = R.style.DialogTopAnimation;
            window.getAttributes().gravity = Gravity.TOP | Gravity.CENTER;
            window.setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
            window.setBackgroundDrawable(new ColorDrawable(android.graphics.Color.TRANSPARENT));
        }
        return dialog;
    }

    public interface ActionListener {

        void accept(boolean dontShowAgain);

    }
}
